@@ -10,35 +10,32 @@ taken from one.
 
 =cut
 
-=head1 SYNOPSIS
+=head1 AUTHOR
 
-   use TinyDNS::Reader;
-
-   my $tmp = TinyDNS::Reader->new( file => "./zones/example.com" );
-   my $dns = $tmp->parse();
-
-   foreach my $record ( @$dns )
-   {
-      print $record . "\n";
-   }
-
-
-=head1 DESCRIPTION
-
-This module contains code for reading a zone-file which has been
-created for use with L<DJB's tinydns|http://cr.yp.to/djbdns/tinydns.html>.
-
-A zonefile may be parsed and turned into a series of L<TinyDNS::Record> objects,
-one for each valid record which is found.
-
-If you wish to merge multiple records, referring to the same hostname, you should also consult the documentation for the L<TinyeDNS::Reader::Merged> module.
+Steve Kemp <steve@steve.org.uk>
 
 =cut
 
-=head1 METHODS
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2014 Steve Kemp <steve@steve.org.uk>.
+
+This code was developed for an online Git-based DNS hosting solution,
+which can be found at:
+
+=over 8
+
+=item *
+https://dns-api.com/
+
+=back
+
+This library is free software. You can modify and or distribute it under
+the same terms as Perl itself.
 
 =cut
 
+
 use strict;
 use warnings;
 
@@ -46,14 +43,14 @@ package TinyDNS::Reader;
 
 use TinyDNS::Record;
 
-our $VERSION = '0.7.7';
+our $VERSION='0.3';
 
 
+=begin doc
 
-=head2 new
+Constructor.  We should be given either a "file" or "text" parameter.
 
-The constructor should be given either a "C<file>" or "C<text>" parameter,
-containing the filename to parse, or the text to parse, respectively.
+=end doc
 
 =cut
 
@@ -75,7 +72,7 @@ sub new
     }
     else
     {
-        die "Missing 'text' or 'file' argument.";
+        die "Missing 'data' or 'file' argument.";
     }
 
     return $self;
@@ -112,10 +109,11 @@ sub _readFile
 }
 
 
-=head2 parse
+=begin doc
 
-Process and return an array of L<TinyDNS::Records> from the data contained
-in the file specified by our constructor, or the scalar reference.
+Process and return an array of L<TinyDNS::Records> from the data.
+
+=end doc
 
 =cut
 
@@ -128,31 +126,23 @@ sub parse
     foreach my $line ( split( /[\n\r]/, $self->{ 'data' } ) )
     {
         chomp($line);
-
-        # Skip empty lines.
         next if ( !$line || !length($line) );
 
-        # Strip trailing comments.
-        $line =~ s/#.*$//s;
-
-        # Skip empty lines.
-        next if ( !$line || !length($line) );
+        #
+        #  Ignore comments
+        #
+        next if ( $line =~ /^\s*#/ );
 
         #
         #  Ignore "." + ":" records
         #
         next if ( $line =~ /^\s*[:.]/ );
 
-        #
-        #  Ensure the line is lower-cased
-        #
-        $line = lc($line);
-
         #
         #  Construct a new object, and add it to the list.
         #
         my $rec = TinyDNS::Record->new($line);
-        push( @$records, $rec ) if ($rec);
+        push( @$records, $rec ) if ( $rec );
     }
 
     return ($records);
@@ -160,29 +150,3 @@ sub parse
 
 
 1;
-
-
-=head1 AUTHOR
-
-Steve Kemp <steve@steve.org.uk>
-
-=cut
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2014-2015 Steve Kemp <steve@steve.org.uk>.
-
-This code was developed for an online Git-based DNS hosting solution,
-which can be found at:
-
-=over 8
-
-=item *
-https://dns-api.com/
-
-=back
-
-This library is free software. You can modify and or distribute it under
-the same terms as Perl itself.
-
-=cut
