@@ -1,7 +1,7 @@
 
 =head1 NAME
 
-TinyDNS::Reader::Merged - Read a TinyDNS file and merge records.
+TinyDNS::Reader::Merger - Read a TinyDNS file and merge records.
 
 =head1 DESCRIPTION
 
@@ -45,8 +45,28 @@ Use it as a drop-in replacing for L<TinyDNS::Reader>.
 
 =cut
 
+=head1 AUTHOR
 
-=head2 METHODS
+Steve Kemp <steve@steve.org.uk>
+
+=cut
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2014 Steve Kemp <steve@steve.org.uk>.
+
+This code was developed for an online Git-based DNS hosting solution,
+which can be found at:
+
+=over 8
+
+=item *
+https://dns-api.com/
+
+=back
+
+This library is free software. You can modify and or distribute it under
+the same terms as Perl itself.
 
 =cut
 
@@ -59,13 +79,14 @@ use strict;
 use warnings;
 
 
-=head2 new
+=begin doc
 
 Constructor.
 
-This module expects to be given a C<file> parameter, pointing to a
-file which can be parsed, or a C<text> parameter containing the text of the
-records to parse.
+This module expects to be given a file parameter, pointing to a
+file which can be parsed.
+
+=end doc
 
 =cut
 
@@ -80,29 +101,21 @@ sub new
     #
     #  Create our child object.
     #
-    if ( $supplied{ 'file' } )
-    {
-        $self->{ 'obj' } = TinyDNS::Reader->new( file => $supplied{ 'file' } );
-    }
-    elsif ( $supplied{ 'text' } )
-    {
-        $self->{ 'obj' } = TinyDNS::Reader->new( text => $supplied{ 'text' } );
-    }
-    else
-    {
-        die "Missing 'text' or 'file' argument";
-    }
+    die "No file" unless ( $supplied{ 'file' } );
+    $self->{ 'obj' } = TinyDNS::Reader->new( file => $supplied{ 'file' } );
     return $self;
 }
 
 
-=head2 parse
+=begin doc
 
 Parse the records and return a merged set.
 
 The parsing is delegated to L<TinyDNS::Reader>, so all supported record-types
 work as expected.
 
+=end doc
+
 =cut
 
 sub parse
@@ -117,23 +130,19 @@ sub parse
     #
     my $res;
 
-    my %seen = ();
+    my %seen;
 
     foreach my $r (@$records)
     {
-
-        # Test that the record was recognized.
-        next unless ( $r->valid() );
-
         my $name = $r->name();
         my $type = $r->type();
         my $val  = $r->value();
         my $ttl  = $r->ttl();
-        my $hash = $r->hash();
 
         # skip if we've seen this name+type pair before.
         next if ( $seen{ $name }{ $type } );
 
+
         #
         #  Look for other values with the same type.
         #
@@ -141,16 +150,9 @@ sub parse
         #
         foreach my $x (@$records)
         {
-
-            # Test that the record was recognized.
-            next if ( !$x->valid() );
-
             my $name2 = $x->name();
             my $type2 = $x->type();
             my $val2  = $x->value();
-            my $hash2 = $x->hash();
-
-            next if ( $hash eq $hash2 );
 
             #
             #  If this record has the same name/type as the
@@ -187,29 +189,3 @@ sub parse
 }
 
 1;
-
-
-=head1 AUTHOR
-
-Steve Kemp <steve@steve.org.uk>
-
-=cut
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2014-2015 Steve Kemp <steve@steve.org.uk>.
-
-This code was developed for an online Git-based DNS hosting solution,
-which can be found at:
-
-=over 8
-
-=item *
-https://dns-api.com/
-
-=back
-
-This library is free software. You can modify and or distribute it under
-the same terms as Perl itself.
-
-=cut
