@@ -12,16 +12,13 @@ It is not quite valid because:
 =over 8
 
 =item *
-We ignore SOA records, which Amazon would handle for us.
+We ignore NS and SOA records, which Amazon would handle for us.
 
 =item *
 Our TXT records handling uses "T" not ":".
 
 =item *
-Our SRV records are non-standard.
-
-=item *
-Our MX record handling allows a name to be set without IP.
+Our MX record handling allows a name to be set with no IP.
 
 =back
 
@@ -29,10 +26,32 @@ There are probably other differences.
 
 =cut
 
-=head1 METHODS
+=head1 AUTHOR
+
+Steve Kemp <steve@steve.org.uk>
 
 =cut
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2014 Steve Kemp <steve@steve.org.uk>.
+
+This code was developed for an online Git-based DNS hosting solution,
+which can be found at:
+
+=over 8
+
+=item *
+https://dns-api.com/
+
+=back
+
+This library is free software. You can modify and or distribute it under
+the same terms as Perl itself.
+
+=cut
+
+
 use strict;
 use warnings;
 
@@ -45,16 +64,17 @@ use Carp;
 #
 #  Allow our object to treated as a string.
 #
-use overload '""' => 'stringify';
+use overload'""' => 'stringify';
 
 
 
-=head2 new
+=begin doc
 
-Constructor, which sets the type of the object.
+Constructor.
 
-The constructor is expected to be passed a valid line of text which
-describes a single record, for example C<+example.example.com:1.2.3.4:200>.
+Set the type of the object.
+
+=end doc
 
 =cut
 
@@ -66,17 +86,6 @@ sub new
     my $self = {};
     bless( $self, $class );
 
-
-    #
-    #  Ensure we process as lower-case
-    #
-    $line = lc($line);
-
-    #
-    #  Record the line we were created with.
-    #
-    $self->{ 'input' } = $line;
-
     #
     #  The record-type is the first character.
     #
@@ -102,56 +111,18 @@ sub new
     #
     if ( ( $rec eq '+' ) || ( $rec eq '=' ) )
     {
-
         # name : ipv4 : ttl
         $self->{ 'type' }  = "A";
         $self->{ 'name' }  = $data[0];
         $self->{ 'value' } = $data[1];
         $self->{ 'ttl' }   = $data[2] || 300;
     }
-    elsif ( $rec eq '_' )
-    {
-
-        # The long-form is:
-        #  $name.$proto.$domain : $hostname : $port : $prior : $weight : $ttl
-        #
-        # The short-form is much more common and useful:
-        #  $name.$proto.$domain : $hostname : $port : $ttl
-        #
-        $self->{ 'type' } = "SRV";
-        $self->{ 'name' } = "_" . $data[0];
-
-        if ( scalar(@data) == 4 )
-        {
-            my $host = $data[1] || 0;
-            my $port = $data[2] || 0;
-            my $ttl  = $data[3] || 300;
-
-            # Bogus priority + weight
-            $self->{ 'value' } = "1 10 $port $host";
-            $self->{ 'ttl' }   = $ttl;
-        }
-        else
-        {
-            my $host     = $data[1] || 0;
-            my $port     = $data[2] || 0;
-            my $priority = $data[3] || 1;
-            my $weight   = $data[4] || 10;
-            my $ttl      = $data[5] || 300;
-
-            # Bogus priority + weight
-            $self->{ 'value' } = "$priority $weight $port $host";
-            $self->{ 'ttl' }   = $ttl;
-        }
-
-    }
     elsif ( $rec eq '6' )
     {
-
         # name : ipv6 : ttl
-        $self->{ 'type' } = "AAAA";
-        $self->{ 'name' } = $data[0];
-        $self->{ 'ttl' }  = $data[2] || 300;
+        $self->{ 'type' }  = "AAAA";
+        $self->{ 'name' }  = $data[0];
+        $self->{ 'ttl' } = $data[2] || 300;
 
         #
         #  Convert an IPv6 record of the form:
@@ -161,49 +132,33 @@ sub new
         #
         my $ipv6 = $data[1];
         my @tmp  = ( $ipv6 =~ m/..../g );
-        $self->{ 'value' } = join( ":", @tmp );
+        $self->{'value'} = join( ":", @tmp );
     }
     elsif ( $rec eq '@' )
     {
-
         #
-        # @name:destination:priority:TTL
+        # @xxx:name:ttl
+        # @xxx:[ip]:name:ttl
         #
         if ( scalar(@data) == 4 )
         {
             $self->{ 'type' }     = "MX";
-            $self->{ 'name' }     = $data[0];
-            $self->{ 'priority' } = $data[2] || "15";
-            $self->{ 'ttl' }      = $data[3] || 300;
-            $self->{ 'value' }    = $self->{ 'priority' } . " " . $data[1];
+            $self->{'name'} = $data[0];
+            $self->{ 'priority' } = $data[3] || "15";
+            $self->{ 'ttl' }      = $data[4] || 300;
+            $self->{ 'value' }    = $self->{'priority'} . " " . $data[2];
         }
         if ( scalar(@data) == 3 )
         {
-            #
-            # @name:destination:priority
-            #
             $self->{ 'type' }     = "MX";
-            $self->{ 'name' }     = $data[0];
+            $self->{'name'} = $data[0];
             $self->{ 'priority' } = $data[2] || "15";
-            $self->{ 'ttl' }      = 300;
-            $self->{ 'value' }    = $self->{ 'priority' } . " " . $data[1];
+            $self->{ 'ttl' }      = $data[3] || 300;
+            $self->{ 'value' }    = $self->{'priority'} . " " . $data[1];
         }
     }
-    elsif ( $rec eq '&' )
-    {
-
-        #
-        #  NS
-        #   &host.example.com:IGNORED:ns1.secure.net:ttl
-        #
-        $self->{ 'type' }  = "NS";
-        $self->{ 'name' }  = $data[0];
-        $self->{ 'value' } = $data[2];
-        $self->{ 'ttl' }   = $data[3] || 300;
-    }
     elsif ( ( $rec eq 'c' ) || ( $rec eq 'C' ) )
     {
-
         #
         # name :  dest : [ttl]
         #
@@ -214,16 +169,15 @@ sub new
     }
     elsif ( ( $rec eq 't' ) || ( $rec eq 'T' ) )
     {
-
         #
         # name : "data " : [TTL]
         #
-        if ( $line =~ /([^:]+):"([^"]+)":*([0-9]*)$/ )
+        if ( $line =~ /([^:]+):"([^"]+)":([0-9]+)$/ )
         {
-            $self->{ 'type' }  = "TXT";
-            $self->{ 'name' }  = $1;
-            $self->{ 'value' } = "\"$2\"";
-            $self->{ 'ttl' }   = $3 || 3600;
+            $self->{'type'} = "TXT";
+            $self->{'name'} = $1;
+            $self->{'value'} ="\"$2\"";
+            $self->{'ttl'} =$3;
         }
         else
         {
@@ -232,11 +186,10 @@ sub new
     }
     elsif ( $rec eq '^' )
     {
-
         #
         #  ptr : "rdns " : [TTL]
         #
-        $self->{ 'type' }  = "PTR";
+        $self->{'type'} = "PTR";
         $self->{ 'name' }  = $data[0];
         $self->{ 'value' } = $data[1];
         $self->{ 'ttl' }   = $data[2] || 300;
@@ -244,30 +197,18 @@ sub new
     else
     {
         carp "Unknown record type [$rec]: $line";
-        return;
+        return undef;
     }
     return $self;
 
 }
 
 
-=head2 input
+=begin doc
 
-Return the text that this record was created with.
+Is the given record valid?  If it has a type then it must be.
 
-=cut
-
-sub input
-{
-    my ($self) = (@_);
-
-    return ( $self->{ 'input' } );
-}
-
-
-=head2 valid
-
-Is this record valid?  Return 0 or 1 as appropriate.
+=end doc
 
 =cut
 
@@ -279,9 +220,11 @@ sub valid
 }
 
 
-=head2 type
+=begin doc
 
-Return the type this record has, such as "A", "AAAA", "NS", etc.
+Get the type of record this object holds.
+
+=end doc
 
 =cut
 
@@ -293,32 +236,27 @@ sub type
 }
 
 
-=head2 ttl
+=begin doc
 
-Return the TTL of this recrd.
+Get the TTL of this object.
 
-If no TTL was explicitly specified we default to 300 seconds, or five minutes.
+=end doc
 
 =cut
 
 sub ttl
 {
     my ($self) = (@_);
-
-    if ( $self->{ 'ttl' } &&
-         $self->{ 'ttl' } =~ /^([0-9]+)$/ )
-    {
-        return $self->{ 'ttl' };
-    }
-
-    return 300;
+    return ( $self->{ 'ttl' } || 300 );
 }
 
 
-=head2 name
+=begin doc
 
 Get the name of this record.
 
+=end doc
+
 =cut
 
 sub name
@@ -328,10 +266,12 @@ sub name
 }
 
 
-=head2 value
+=begin doc
 
 Get the value of this record.
 
+=end doc
+
 =cut
 
 sub value
@@ -342,12 +282,13 @@ sub value
 }
 
 
-=head2 add
+=begin doc
 
 Add a new value to the existing record.
 
-This is used by the L<TinyDNS::Reader::Merged> module.
+This is added by the L<TinyDNS::Reader::Merged> module.
 
+=end doc
 
 =cut
 
@@ -371,9 +312,11 @@ sub add
 }
 
 
-=head2 stringify
+=begin doc
 
-Convert the record to a string, suitable for printing.
+Conver the record to a string, suitable for printing.
+
+=end doc
 
 =cut
 
@@ -390,49 +333,4 @@ sub stringify
 }
 
 
-=head2 hash
-
-Return a consistent hash of the record.
-
-=cut
-
-sub hash
-{
-    my ($self) = (@_);
-
-    my $hash;
-    $hash .= $self->type();
-    $hash .= $self->name();
-    $hash .= $self->value();
-    $hash .= $self->ttl();
-
-    return ($hash);
-}
-
 1;
-
-
-=head1 AUTHOR
-
-Steve Kemp <steve@steve.org.uk>
-
-=cut
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2014-2015 Steve Kemp <steve@steve.org.uk>.
-
-This code was developed for an online Git-based DNS hosting solution,
-which can be found at:
-
-=over 8
-
-=item *
-https://dns-api.com/
-
-=back
-
-This library is free software. You can modify and or distribute it under
-the same terms as Perl itself.
-
-=cut
